@@ -2,7 +2,7 @@ package Mojo::IOLoop::ForkCall;
 
 use Mojo::Base 'Mojo::EventEmitter';
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;
 
 use Mojo::IOLoop;
@@ -100,7 +100,8 @@ sub _run {
       $self->emit( error => $@ ) if $@ and $self;
 
       # emit the finish event, emit error if IT fails
-      $self->emit_safe( finish => @$res ) if $self;
+      eval { $self->emit( finish => @$res ) if $self };
+      $self->emit( error => $@ ) if $@ and $self;
 
       waitpid $child, 0;
     });
